From 57a0e0685875944565ffae43c7234062a83210e8 Mon Sep 17 00:00:00 2001
From: Markus Blatt <mblatt@dune-project.org>
Date: Fri, 15 Mar 2013 11:45:31 +0000
Subject: [PATCH] Use <package>_ROOT for user provided locations instead of
 <package>_PREFIX <package>_DIR.

The latter is the location of the package configuration files.

[[Imported from SVN: r1899]]
---
 cmake/modules/FindSuperLU.cmake | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/cmake/modules/FindSuperLU.cmake b/cmake/modules/FindSuperLU.cmake
index 7f539f9c2..b1d42ee94 100644
--- a/cmake/modules/FindSuperLU.cmake
+++ b/cmake/modules/FindSuperLU.cmake
@@ -3,7 +3,7 @@
 # SuperLU must be a version released after the year 2005.
 #
 # Variables used by this module which you may want to set:
 # SUPERLU_PREFIX          Path list to search for SuperLU
 #
 # Sets the follwing variable:
 #
@@ -37,7 +37,7 @@ endif(NOT BLAS_FOUND)
 # look for header files, only at positions given by the user
 find_path(SUPERLU_INCLUDE_DIR
   NAMES supermatrix.h
-  PATHS ${SUPERLU_PREFIX}
+  PATHS ${SUPERLU_ROOT}
   PATH_SUFFIXES "superlu" "include/superlu" "include" "SRC"
   NO_DEFAULT_PATH
 )
@@ -51,7 +51,7 @@ find_path(SUPERLU_INCLUDE_DIR
 # look for library, only at positions given by the user
 find_library(SUPERLU_LIBRARY
   NAMES "superlu_4.3" "superlu_4.2" "superlu_4.1" "superlu_4.0" "superlu_3.1" "superlu_3.0" "superlu"
-  PATHS ${SUPERLU_PREFIX}
+  PATHS ${SUPERLU_ROOT}
   PATH_SUFFIXES "lib" "lib32" "lib64"
   NO_DEFAULT_PATH
 )
@@ -3,7 +3,7 @@
 #
 # Variables used by this module which you may want to set:
-# SUPERLU_PREFIX          Path list to search for SuperLU
+# SUPERLU_ROOT          Path list to search for SuperLU
 #
 # Sets the follwing variable:
-- 
GitLab